searchNodes=[{"doc":"Utilities for working with SIP-URIs.This module provides functions for working with URIs (for example, parsing SIP-URIs, encoding parameters or header strings).","ref":"Sippet.URI.html","title":"Sippet.URI","type":"module"},{"doc":"Checks if the character is an &quot;hnv-unreserved&quot; character in a SIP-URI.Examplesiex&gt; Sippet.URI.char_hnv_unreserved?(?:) true","ref":"Sippet.URI.html#char_hnv_unreserved?/1","title":"Sippet.URI.char_hnv_unreserved?/1","type":"function"},{"doc":"Checks if the character is an &quot;param-unreserved&quot; character in a SIP-URI.Examplesiex&gt; Sippet.URI.char_param_unreserved?(?~) false","ref":"Sippet.URI.html#char_param_unreserved?/1","title":"Sippet.URI.char_param_unreserved?/1","type":"function"},{"doc":"Checks if the character is an &quot;unreserved&quot; character in a SIP-URI.Examplesiex&gt; Sippet.URI.char_unreserved?(?~) true","ref":"Sippet.URI.html#char_unreserved?/1","title":"Sippet.URI.char_unreserved?/1","type":"function"},{"doc":"Decodes a &quot;headers&quot; string into a map.Given a &quot;headers&quot; string of the form of ?key1=value1&amp;key2=value2..., this function inserts each key-value pair in the query string as one entry in the given map. Keys and values in the resulting map will be binaries. Keys and values will be percent-unescaped.Use headers_decoder/1 if you want to iterate over each value manually.Examplesiex&gt; Sippet.URI.decode_headers(&quot;?foo=1&amp;bar=2&quot;) %{&quot;bar&quot; =&gt; &quot;2&quot;, &quot;foo&quot; =&gt; &quot;1&quot;}","ref":"Sippet.URI.html#decode_headers/2","title":"Sippet.URI.decode_headers/2","type":"function"},{"doc":"Decodes a &quot;uri-parameters&quot; string into a map.Given a &quot;uri-parameters&quot; string of the form of ;key1=value1;key2=value2..., this function inserts each key-value pair in the query string as one entry in the given map. Keys and values in the resulting map will be binaries. Keys and values will be percent-unescaped.Use parameters_decoder/1 if you want to iterate over each value manually.Examplesiex&gt; Sippet.URI.decode_parameters(&quot;;foo=1;bar=2&quot;) %{&quot;bar&quot; =&gt; &quot;2&quot;, &quot;foo&quot; =&gt; &quot;1&quot;}","ref":"Sippet.URI.html#decode_parameters/2","title":"Sippet.URI.decode_parameters/2","type":"function"},{"doc":"Returns the default port for a given SIP scheme. If the scheme is unknown to the Sippet.URI module, this function returns nil.Examplesiex&gt; Sippet.URI.default_port(&quot;sip&quot;) 5060 iex&gt; Sippet.URI.default_port(&quot;ponzi&quot;) nil","ref":"Sippet.URI.html#default_port/1","title":"Sippet.URI.default_port/1","type":"function"},{"doc":"Encodes an enumerable into a &quot;headers&quot; string.Takes an enumerable that enumerates as a list of two-element tuples (e.g., a map or a keyword list) and returns a string in the form of ?key1=value1&amp;key2=value2... where keys and values are encoded as per encode_header/1. Keys and values can be any term that implements the String.Chars protocol, except lists which are explicitly forbidden.Examplesiex&gt; hd = %{&quot;foo&quot; =&gt; 1, &quot;bar&quot; =&gt; 2} iex&gt; Sippet.URI.encode_headers(hd) &quot;?bar=2&amp;foo=1&quot; iex&gt; headers = %{&quot;key&quot; =&gt; &quot;value with spaces&quot;} iex&gt; Sippet.URI.encode_headers(headers) &quot;?key=value%20with%20spaces&quot; iex&gt; Sippet.URI.encode_headers %{key: [:a, :list]} ** (ArgumentError) encode_headers/1 values cannot be lists, got: [:a, :list]","ref":"Sippet.URI.html#encode_headers/1","title":"Sippet.URI.encode_headers/1","type":"function"},{"doc":"Encodes a string as &quot;hname&quot; / &quot;hvalue&quot;.Exampleiex&gt; Sippet.URI.encode_hnvchar(&quot;put: it+й&quot;) &quot;put:%20it+%D0%B9&quot;","ref":"Sippet.URI.html#encode_hnvchar/1","title":"Sippet.URI.encode_hnvchar/1","type":"function"},{"doc":"Encodes a string as &quot;paramchar&quot;.Exampleiex&gt; Sippet.URI.encode_paramchar(&quot;put: it+й&quot;) &quot;put:%20it+%D0%B9&quot;","ref":"Sippet.URI.html#encode_paramchar/1","title":"Sippet.URI.encode_paramchar/1","type":"function"},{"doc":"Encodes an enumerable into a &quot;uri-parameters&quot; string.Takes an enumerable that enumerates as a list of two-element tuples (e.g., a map or a keyword list) and returns a string in the form of ;key1=value1;key2=value2... where keys and values are encoded as per encode_paramchar/1. Keys and values can be any term that implements the String.Chars protocol, except lists which are explicitly forbidden.Examplesiex&gt; hd = %{&quot;foo&quot; =&gt; 1, &quot;bar&quot; =&gt; 2} iex&gt; Sippet.URI.encode_parameters(hd) &quot;;bar=2;foo=1&quot; iex&gt; parameters = %{&quot;key&quot; =&gt; &quot;value with spaces&quot;} iex&gt; Sippet.URI.encode_parameters(parameters) &quot;;key=value%20with%20spaces&quot; iex&gt; Sippet.URI.encode_parameters %{key: [:a, :list]} ** (ArgumentError) encode_parameters/1 values cannot be lists, got: [:a, :list]","ref":"Sippet.URI.html#encode_parameters/1","title":"Sippet.URI.encode_parameters/1","type":"function"},{"doc":"Checks whether two SIP-URIs are equivalent.This function follows the RFC 3261 rules specified in section 19.1.4.Examplesiex&gt; a = Sippet.URI.parse!(&quot;sip:%61lice@atlanta.com;transport=TCP&quot;) iex&gt; b = Sippet.URI.parse!(&quot;sip:alice@atlanta.com;transport=tcp&quot;) iex&gt; Sippet.URI.equivalent(a, b) true","ref":"Sippet.URI.html#equivalent/2","title":"Sippet.URI.equivalent/2","type":"function"},{"doc":"Returns a stream of two-element tuples representing key-value pairs in the given headers.Key and value in each tuple will be binaries and will be percent-unescaped.Examplesiex&gt; Sippet.URI.headers_decoder(&quot;?foo=1&amp;bar=2&quot;) |&gt; Enum.to_list() [{&quot;foo&quot;, &quot;1&quot;}, {&quot;bar&quot;, &quot;2&quot;}]","ref":"Sippet.URI.html#headers_decoder/1","title":"Sippet.URI.headers_decoder/1","type":"function"},{"doc":"Checks whether two SIP-URIs are equivalent, but using more lazy rules.Examplesiex&gt; a = Sippet.URI.parse!(&quot;sip:atlanta.com;transport=UDP&quot;) iex&gt; b = Sippet.URI.parse!(&quot;sip:atlanta.com:5060&quot;) iex&gt; Sippet.URI.lazy_equivalent(a, b) true","ref":"Sippet.URI.html#lazy_equivalent/2","title":"Sippet.URI.lazy_equivalent/2","type":"function"},{"doc":"Returns a stream of two-element tuples representing key-value pairs in the given parameters.Key and value in each tuple will be binaries and will be percent-unescaped.Examplesiex&gt; Sippet.URI.parameters_decoder(&quot;;foo=1;bar=2&quot;) |&gt; Enum.to_list() [{&quot;foo&quot;, &quot;1&quot;}, {&quot;bar&quot;, &quot;2&quot;}]","ref":"Sippet.URI.html#parameters_decoder/1","title":"Sippet.URI.parameters_decoder/1","type":"function"},{"doc":"Parses a well-formed SIP-URI reference into its components.Note this function expects a well-formed SIP-URI and does not perform any validation. See the &quot;Examples&quot; section below for examples of how Sippet.URI.parse/1 can be used to parse a wide range of URIs. When a SIP-URI is given without a port, the value returned by Sippet.URI.default_port/1 for the SIP-URI's scheme is used for the :port field. If a %Sippet.URI{} struct is given to this function, this function returns it unmodified.Examplesiex&gt; Sippet.URI.parse(&quot;sip:user@host?Call-Info=%3Chttp://www.foo.com%3E&amp;Subject=foo&quot;) {:ok, %Sippet.URI{scheme: &quot;sip&quot;, userinfo: &quot;user&quot;, authority: &quot;user@host&quot;, host: &quot;host&quot;, port: 5060, parameters: nil, headers: &quot;?Call-Info=%3Chttp://www.foo.com%3E&amp;Subject=foo&quot;}} iex&gt; Sippet.URI.parse(&quot;sip:user@host;transport=FOO&quot;) {:ok, %Sippet.URI{scheme: &quot;sip&quot;, userinfo: &quot;user&quot;, authority: &quot;user@host&quot;, host: &quot;host&quot;, port: 5060, parameters: &quot;;transport=FOO&quot;, headers: nil}} iex&gt; Sippet.URI.parse(&quot;sip:user@host&quot;) {:ok, %Sippet.URI{scheme: &quot;sip&quot;, userinfo: &quot;user&quot;, authority: &quot;user@host&quot;, host: &quot;host&quot;, port: 5060, parameters: nil, headers: nil}}","ref":"Sippet.URI.html#parse/1","title":"Sippet.URI.parse/1","type":"function"},{"doc":"Parses a well-formed SIP-URI reference into its components.If invalid, raises an exception.","ref":"Sippet.URI.html#parse!/1","title":"Sippet.URI.parse!/1","type":"function"},{"doc":"Decodes an encoded string, transforming any percent encoding back to corresponding characters.Examplesiex&gt; Sippet.URI.percent_unescape(&quot;%3Call%20in%2F&quot;) &quot;&lt;all in/&quot;","ref":"Sippet.URI.html#percent_unescape/1","title":"Sippet.URI.percent_unescape/1","type":"function"},{"doc":"Returns the string representation of the given Sippet.URI struct.Examplesiex&gt; Sippet.URI.to_string(Sippet.URI.parse!(&quot;sip:foo@bar.com&quot;)) &quot;sip:foo@bar.com&quot; iex&gt; Sippet.URI.to_string(%URI{scheme: &quot;foo&quot;, host: &quot;bar.baz&quot;}) &quot;foo:bar.baz&quot;","ref":"Sippet.URI.html#to_string/1","title":"Sippet.URI.to_string/1","type":"function"},{"doc":"","ref":"Sippet.URI.html#t:t/0","title":"Sippet.URI.t/0","type":"type"}]